==> apache-ignite-2.7.0-src.zip: apache-ignite-2.7.0-src/modules/platforms/dotnet/Apache.Ignite/Config/ConfigValueParser.cs <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace Apache.Ignite.Config
{
    using System;

    /// <summary>
    /// Parses Ignite config values.
    /// </summary>
    internal class ConfigValueParser
    {
        /// <summary>
        /// Parses provided string to int. Throws a custom exception if failed.
        /// </summary>
        public static int ParseInt(string value, string propertyName)
        {
            int result;

            if (int.TryParse(value, out result))
                return result;

            throw new InvalidOperationException(
                string.Format("Failed to configure Ignite: property '{0}' has value '{1}', which is not an integer.",
                    propertyName, value));
        }
    }
}

==> apache-ignite-2.17.0-src.zip: apache-ignite-2.17.0-src/modules/platforms/dotnet/Apache.Ignite/Config/ConfigValueParser.cs <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace Apache.Ignite.Config
{
    using System;

    /// <summary>
    /// Parses Ignite config values.
    /// </summary>
    internal static class ConfigValueParser
    {
        /// <summary>
        /// Parses provided string to int. Throws a custom exception if failed.
        /// </summary>
        public static int ParseInt(string value, string propertyName)
        {
            int result;

            if (int.TryParse(value, out result))
                return result;

            throw new InvalidOperationException(
                string.Format("Failed to configure Ignite: property '{0}' has value '{1}', which is not an integer.",
                    propertyName, value));
        }
    }
}
